@@ -5,80 +5,89 @@
  */
 
 #include "ScreenshotsModel.h"
-#include <resources/AbstractResource.h>
 #include "libdiscover_debug.h"
+#include "utils.h"
+#include <resources/AbstractResource.h>
 // #include <QAbstractItemModelTester>
 
-ScreenshotsModel::ScreenshotsModel(QObject* parent)
+ScreenshotsModel::ScreenshotsModel(QObject *parent)
     : QAbstractListModel(parent)
     , m_resource(nullptr)
-{}
+{
+}
 
-QHash< int, QByteArray > ScreenshotsModel::roleNames() const
+QHash<int, QByteArray> ScreenshotsModel::roleNames() const
 {
     QHash<int, QByteArray> roles = QAbstractItemModel::roleNames();
     roles.insert(ThumbnailUrl, "small_image_url");
     roles.insert(ScreenshotUrl, "large_image_url");
+    roles.insert(IsAnimatedRole, "isAnimated");
     return roles;
 }
 
-void ScreenshotsModel::setResource(AbstractResource* res)
+void ScreenshotsModel::setResource(AbstractResource *res)
 {
-    if(res == m_resource)
+    if (res == m_resource)
         return;
 
-    if(m_resource) {
+    if (m_resource) {
         disconnect(m_resource, &AbstractResource::screenshotsFetched, this, &ScreenshotsModel::screenshotsFetched);
     }
     m_resource = res;
     Q_EMIT resourceChanged(res);
-    
-    if(res) {
+
+    beginResetModel();
+    m_screenshots.clear();
+    endResetModel();
+
+    if (res) {
         connect(m_resource, &AbstractResource::screenshotsFetched, this, &ScreenshotsModel::screenshotsFetched);
         res->fetchScreenshots();
     } else
         qCWarning(LIBDISCOVER_LOG) << "empty resource!";
 }
 
-AbstractResource* ScreenshotsModel::resource() const
+AbstractResource *ScreenshotsModel::resource() const
 {
     return m_resource;
 }
 
-void ScreenshotsModel::screenshotsFetched(const QList< QUrl >& thumbnails, const QList< QUrl >& screenshots)
+void ScreenshotsModel::screenshotsFetched(const Screenshots &screenshots)
 {
-    Q_ASSERT(thumbnails.count()==screenshots.count());
-    if (thumbnails.isEmpty())
+    if (screenshots.isEmpty())
         return;
-    
-    beginInsertRows(QModelIndex(), m_thumbnails.size(), m_thumbnails.size()+thumbnails.size()-1);
-    m_thumbnails += thumbnails;
+
+    beginInsertRows(QModelIndex(), m_screenshots.size(), m_screenshots.size() + screenshots.size() - 1);
     m_screenshots += screenshots;
     endInsertRows();
-    emit countChanged();
+    Q_EMIT countChanged();
 }
 
-QVariant ScreenshotsModel::data(const QModelIndex& index, int role) const
+QVariant ScreenshotsModel::data(const QModelIndex &index, int role) const
 {
-    if(!index.isValid() || index.parent().isValid())
+    if (!index.isValid() || index.parent().isValid())
         return QVariant();
-    
-    switch(role) {
-        case ThumbnailUrl: return m_thumbnails[index.row()];
-        case ScreenshotUrl: return m_screenshots[index.row()];
+
+    switch (role) {
+    case ThumbnailUrl:
+        return m_screenshots[index.row()].thumbnail;
+    case ScreenshotUrl:
+        return m_screenshots[index.row()].screenshot;
+    case IsAnimatedRole:
+        return m_screenshots[index.row()].isAnimated;
     }
-    
+
     return QVariant();
 }
 
-int ScreenshotsModel::rowCount(const QModelIndex& parent) const
+int ScreenshotsModel::rowCount(const QModelIndex &parent) const
 {
     return !parent.isValid() ? m_screenshots.count() : 0;
 }
 
 QUrl ScreenshotsModel::screenshotAt(int row) const
 {
-    return m_screenshots[row];
+    return m_screenshots[row].screenshot;
 }
 
 int ScreenshotsModel::count() const
@@ -86,16 +95,19 @@ int ScreenshotsModel::count() const
     return m_screenshots.count();
 }
 
-void ScreenshotsModel::remove(const QUrl& url)
+void ScreenshotsModel::remove(const QUrl &url)
 {
-    int idxRemove = m_thumbnails.indexOf(url);
-    if (idxRemove>=0) {
+    int idxRemove = kIndexOf(m_screenshots, [url](const Screenshot &s) {
+        return s.thumbnail == url || s.screenshot == url;
+    });
+    if (idxRemove >= 0) {
         beginRemoveRows({}, idxRemove, idxRemove);
-        m_thumbnails.removeAt(idxRemove);
         m_screenshots.removeAt(idxRemove);
         endRemoveRows();
-        emit countChanged();
+        Q_EMIT countChanged();
 
         qDebug() << "screenshot removed" << url;
     }
 }
+
+#include "moc_ScreenshotsModel.cpp"
