@@ -44,7 +44,12 @@ void FwupdTransaction::install()
         const QUrl uri(m_app->updateURI());
         setStatus(DownloadingStatus);
         QNetworkAccessManager *manager = new QNetworkAccessManager(this);
-        auto reply = manager->get(QNetworkRequest(uri));
+        auto req = QNetworkRequest(uri);
+
+        const QString userAgent = QString::fromUtf8(fwupd_client_get_user_agent(m_backend->client));
+        req.setHeader(QNetworkRequest::UserAgentHeader, userAgent);
+        req.setAttribute(QNetworkRequest::RedirectPolicyAttribute, QNetworkRequest::NoLessSafeRedirectPolicy);
+        auto reply = manager->get(req);
         QFile *file = new QFile(fileName);
         if (!file->open(QFile::WriteOnly)) {
             qWarning() << "Fwupd Error: Could not open to write" << fileName << uri;
