@@ -1,6 +1,7 @@
 /*
  *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
  *   SPDX-FileCopyrightText: 2013 Lukas Appelhans <l.appelhans@gmx.de>
+ *   SPDX-FileCopyrightText: 2023 Harald Sitter <sitter@kde.org>
  *
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
@@ -12,9 +13,19 @@
 #include "PKTransaction.h"
 #include "PackageKitSourcesBackend.h"
 #include "PackageKitUpdater.h"
+
+#ifdef DISCOVER_USE_STABLE_APPSTREAM
+#include <AppStreamQt5/release.h>
+#include <AppStreamQt5/systeminfo.h>
+#include <AppStreamQt5/utils.h>
+#include <AppStreamQt5/version.h>
+#else
 #include <AppStreamQt/release.h>
+#include <AppStreamQt/systeminfo.h>
 #include <AppStreamQt/utils.h>
 #include <AppStreamQt/version.h>
+#endif
+
 #include <appstream/AppStreamIntegration.h>
 #include <appstream/AppStreamUtils.h>
 #include <appstream/OdrsReviewsBackend.h>
@@ -308,12 +319,26 @@ void PackageKitBackend::reloadPackageList()
         }
         acquireFetching(false);
 
-        const QList<AppStream::Component> distroComponents = m_appdata->componentsById(AppStream::Utils::currentDistroComponentId());
+        const QList<AppStream::Component> distroComponents =
+#if ASQ_CHECK_VERSION(1, 0, 0)
+            m_appdata->componentsById(AppStream::SystemInfo::currentDistroComponentId()).toList();
+#else
+            m_appdata->componentsById(AppStream::Utils::currentDistroComponentId());
+#endif
+
         if (distroComponents.isEmpty()) {
+#if ASQ_CHECK_VERSION(1, 0, 0)
+            qWarning() << "no component found for" << AppStream::SystemInfo::currentDistroComponentId();
+#else
             qWarning() << "no component found for" << AppStream::Utils::currentDistroComponentId();
+#endif
         }
         for (const AppStream::Component &dc : distroComponents) {
+#if ASQ_CHECK_VERSION(1, 0, 0)
+            const auto releases = dc.releasesPlain().entries();
+#else
             const auto releases = dc.releases();
+#endif
             for (const auto &r : releases) {
                 int cmp = AppStream::Utils::vercmpSimple(r.version(), AppStreamIntegration::global()->osRelease()->versionId());
                 if (cmp == 0) {
@@ -551,7 +576,11 @@ QList<AppStream::Component> PackageKitBackend::componentsById(const QString &id)
     if (comps.isEmpty()) {
         comps = m_appdata->componentsByProvided(AppStream::Provided::KindId, id);
     }
+#if ASQ_CHECK_VERSION(1, 0, 0)
+    return comps.toList();
+#else
     return comps;
+#endif
 }
 
 static const auto needsResolveFilter = [](AbstractResource *res) {
@@ -560,7 +589,7 @@ static const auto needsResolveFilter = [](AbstractResource *res) {
 
 class PKResultsStream : public ResultsStream
 {
-public:
+private:
     PKResultsStream(PackageKitBackend *backend, const QString &name)
         : ResultsStream(name)
         , backend(backend)
@@ -576,6 +605,13 @@ public:
         });
     }
 
+public:
+    template<typename... Args>
+    [[nodiscard]] static QPointer<PKResultsStream> create(Args&& ...args)
+    {
+        return new PKResultsStream(std::forward<Args>(args)...);
+    }
+
     void sendResources(const QVector<AbstractResource *> &res, bool waitForResolved = false)
     {
         if (res.isEmpty()) {
@@ -612,8 +648,11 @@ ResultsStream *PackageKitBackend::search(const AbstractResourcesBackend::Filters
     if (!filter.resourceUrl.isEmpty()) {
         return findResourceByPackageName(filter.resourceUrl);
     } else if (!filter.extends.isEmpty()) {
-        auto stream = new PKResultsStream(this, QStringLiteral("PackageKitStream-extends"));
+        auto stream = PKResultsStream::create(this, QStringLiteral("PackageKitStream-extends"));
         auto f = [this, filter, stream] {
+            if (!stream) {
+                return;
+            }
             const auto resources = kTransform<QVector<AbstractResource *>>(m_packages.extendedBy.value(filter.extends), [](AppPackageKitResource *a) {
                 return a;
             });
@@ -625,8 +664,11 @@ ResultsStream *PackageKitBackend::search(const AbstractResourcesBackend::Filters
         return new ResultsStream(QStringLiteral("PackageKitStream-upgradeable"),
                                  kTransform<QVector<AbstractResource *>>(upgradeablePackages())); // No need for it to be a PKResultsStream
     } else if (filter.state == AbstractResource::Installed) {
-        auto stream = new PKResultsStream(this, QStringLiteral("PackageKitStream-installed"));
+        auto stream = PKResultsStream::create(this, QStringLiteral("PackageKitStream-installed"));
         auto f = [this, stream, filter] {
+            if (!stream) {
+                return;
+            }
             const auto toResolve = kFilter<QVector<AbstractResource *>>(m_packages.packages, needsResolveFilter);
 
             auto installedAndNameFilter = [filter](AbstractResource *res) {
@@ -665,8 +707,11 @@ ResultsStream *PackageKitBackend::search(const AbstractResourcesBackend::Filters
         runWhenInitialized(f, stream);
         return stream;
     } else if (filter.search.isEmpty() && !filter.category) {
-        auto stream = new PKResultsStream(this, QStringLiteral("PackageKitStream-all"));
+        auto stream = PKResultsStream::create(this, QStringLiteral("PackageKitStream-all"));
         auto f = [this, filter, stream] {
+            if (!stream) {
+                return;
+            }
             auto resources = kFilter<QVector<AbstractResource *>>(m_packages.packages, [](AbstractResource *res) {
                 return res->type() != AbstractResource::Technical && !qobject_cast<PackageKitResource *>(res)->isCritical()
                     && !qobject_cast<PackageKitResource *>(res)->extendsItself();
@@ -676,15 +721,30 @@ ResultsStream *PackageKitBackend::search(const AbstractResourcesBackend::Filters
         runWhenInitialized(f, stream);
         return stream;
     } else {
-        auto stream = new PKResultsStream(this, QStringLiteral("PackageKitStream-search"));
+        auto stream = PKResultsStream::create(this, QStringLiteral("PackageKitStream-search"));
         const auto f = [this, stream, filter]() {
-            const auto components = !filter.search.isEmpty() ? m_appdata->search(filter.search)
-#if ASQ_CHECK_VERSION(0, 15, 6)
-                                  : filter.category          ? AppStreamUtils::componentsByCategories(m_appdata.get(),
-                                                                                                      filter.category,
-                                                                                                      AppStream::Bundle::KindUnknown)
+            if (!stream) {
+                return;
+            }
+            QList<AppStream::Component> components;
+            if (!filter.search.isEmpty()) {
+#if ASQ_CHECK_VERSION(1, 0, 0)
+                components = m_appdata->search(filter.search).toList();
+#else
+                components = m_appdata->search(filter.search);
 #endif
-                                                             : m_appdata->components();
+#if ASQ_CHECK_VERSION(0, 15, 6)
+            } else if (filter.category) {
+                components = AppStreamUtils::componentsByCategories(m_appdata.get(), filter.category, AppStream::Bundle::KindUnknown);
+#endif
+            } else {
+#if ASQ_CHECK_VERSION(1, 0, 0)
+                components = m_appdata->components().toList();
+#else
+                components = m_appdata->components();
+#endif
+            }
+
             const QSet<QString> ids = kTransform<QSet<QString>>(components, [](const AppStream::Component &comp) {
                 return comp.id();
             });
@@ -707,7 +767,7 @@ void PackageKitBackend::runWhenInitialized(const std::function<void()> &f, QObje
     if (!m_appstreamInitialized) {
         connect(this, &PackageKitBackend::loadedAppStream, stream, f);
     } else {
-        QTimer::singleShot(0, this, f);
+        QTimer::singleShot(0, stream, f); // NOTE `stream` is a child of `this` so this transitively also depends on `this`
     }
 }
 
@@ -721,15 +781,18 @@ PKResultsStream *PackageKitBackend::findResourceByPackageName(const QUrl &url)
             || mime.inherits(QStringLiteral("application/x-tar")) //
             || mime.inherits(QStringLiteral("application/x-zstd-compressed-tar")) //
             || mime.inherits(QStringLiteral("application/x-xz-compressed-tar"))) {
-            return new PKResultsStream(this, QStringLiteral("PackageKitStream-localpkg"), {new LocalFilePKResource(url, this)});
+            return PKResultsStream::create(this, QStringLiteral("PackageKitStream-localpkg"), QVector<AbstractResource *>{new LocalFilePKResource(url, this)}).data();
         }
     } else if (url.scheme() == QLatin1String("appstream")) {
         const auto appstreamIds = AppStreamUtils::appstreamIds(url);
         if (appstreamIds.isEmpty())
             Q_EMIT passiveMessage(i18n("Malformed appstream url '%1'", url.toDisplayString()));
         else {
-            auto stream = new PKResultsStream(this, QStringLiteral("PackageKitStream-appstream-url"));
+            auto stream = PKResultsStream::create(this, QStringLiteral("PackageKitStream-appstream-url"));
             const auto f = [this, appstreamIds, stream]() {
+                if (!stream) {
+                    return;
+                }
                 auto toSend = QSet<AbstractResource *>();
                 toSend.reserve(appstreamIds.size());
                 for (const auto &appstreamId : appstreamIds) {
@@ -748,7 +811,7 @@ PKResultsStream *PackageKitBackend::findResourceByPackageName(const QUrl &url)
             return stream;
         }
     }
-    return new PKResultsStream(this, QStringLiteral("PackageKitStream-unknown-url"), {});
+    return PKResultsStream::create(this, QStringLiteral("PackageKitStream-unknown-url"), QVector<AbstractResource *>{}).data();
 }
 
 template<typename T>
