@@ -3,8 +3,7 @@
  *
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
-#ifndef PACKAGEKITNOTIFIER_H
-#define PACKAGEKITNOTIFIER_H
+#pragma once
 
 #include <BackendNotifierModule.h>
 #include <PackageKit/Transaction>
@@ -45,7 +44,7 @@ private:
     void recheckSystemUpdate();
     void checkOfflineUpdates();
     void setupGetUpdatesTransaction(PackageKit::Transaction *transaction);
-    QProcess *checkAptVariable(const QString &aptconfig, const QLatin1String &varname, const std::function<void(const QStringRef &val)> &func);
+    QProcess *checkAptVariable(const QString &aptconfig, const QLatin1String &varname, const std::function<void(const QStringView &val)> &func);
 
     bool m_needsReboot = false;
     uint m_securityUpdates;
@@ -56,5 +55,3 @@ private:
 
     QHash<QString, PackageKit::Transaction *> m_transactions;
 };
-
-#endif
