@@ -3,8 +3,7 @@
  *
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
-#ifndef PACKAGEKITUPDATER_H
-#define PACKAGEKITUPDATER_H
+#pragma once
 
 #include "PackageKitBackend.h"
 #include <PackageKit/Transaction>
@@ -27,6 +26,7 @@ public:
     ~PackageKitUpdater() override;
 
     void prepare() override;
+    void checkFreeSpace();
 
     bool hasUpdates() const override;
     qreal progress() const override;
@@ -106,5 +106,3 @@ private:
 
     SystemUpgrade *m_upgrade = nullptr;
 };
-
-#endif
