@@ -211,14 +211,21 @@ void RpmOstreeTransaction::processCommand(int exitCode, QProcess::ExitStatus exi
             const QJsonDocument jsonDocument = QJsonDocument::fromJson(m_stdout);
             if (!jsonDocument.isObject()) {
                 qWarning() << "rpm-ostree-backend: Could not parse output as JSON:" << m_prog << m_args;
+                setStatus(Status::DoneWithErrorStatus);
                 return;
             }
 
-            // Get the version stored in .Labels.version
-            const QString newVersion = jsonDocument.object().value("Labels").toObject().value("version").toString();
+            // Get the version stored in 'org.opencontainers.image.version' label
+            QString newVersion =
+                jsonDocument.object().value(QLatin1String("Labels")).toObject().value(QLatin1String("org.opencontainers.image.version")).toString();
             if (newVersion.isEmpty()) {
-                qInfo() << "rpm-ostree-backend: Could not get the version from the container labels";
-                return;
+                // Check the 'version' label for compatibility with older rpm-ostree releases (< v2024.03)
+                newVersion = jsonDocument.object().value(QLatin1String("Labels")).toObject().value(QLatin1String("version")).toString();
+                if (newVersion.isEmpty()) {
+                    qWarning() << "rpm-ostree-backend: Could not get the version from the container labels";
+                    setStatus(Status::DoneWithErrorStatus);
+                    return;
+                }
             }
 
             QVersionNumber newVersionNumber = QVersionNumber::fromString(newVersion);
@@ -233,6 +240,8 @@ void RpmOstreeTransaction::processCommand(int exitCode, QProcess::ExitStatus exi
             // Should never happen
             qWarning() << "rpm-ostree-backend: Error: Unknown resource format. Please file a bug.";
             passiveMessage("rpm-ostree-backend: Error: Unknown resource format. Please file a bug.");
+            setStatus(Status::DoneWithErrorStatus);
+            return;
         }
 
         // Always tell the backend to look for a new major version
@@ -259,6 +268,8 @@ void RpmOstreeTransaction::processCommand(int exitCode, QProcess::ExitStatus exi
         // This should never happen
         qWarning() << "rpm-ostree-backend: Error: Unknown operation requested. Please file a bug.";
         passiveMessage("rpm-ostree-backend: Error: Unknown operation requested. Please file a bug.");
+        setStatus(Status::DoneWithErrorStatus);
+        return;
     }
     setStatus(Status::DoneStatus);
 }
