@@ -17,6 +17,7 @@
 #include <Snapd/MarkdownParser>
 #endif
 
+#include <appstream/AppStreamUtils.h>
 #include <utils.h>
 
 QDebug operator<<(QDebug debug, const QSnapdPlug &plug)
@@ -149,7 +150,7 @@ QString SnapResource::installedVersion() const
 
 QJsonArray SnapResource::licenses()
 {
-    return {QJsonObject{{QStringLiteral("name"), m_snap->license()}}};
+    return AppStreamUtils::licenses(m_snap->license());
 }
 
 #ifdef SNAP_MARKDOWN
@@ -263,7 +264,7 @@ void SnapResource::fetchChangelog()
 
 void SnapResource::fetchScreenshots()
 {
-    QList<QUrl> screenshots;
+    Screenshots screenshots;
 #ifdef SNAP_MEDIA
     for (int i = 0, c = m_snap->mediaCount(); i < c; ++i) {
         QScopedPointer<QSnapdMedia> media(m_snap->media(i));
@@ -276,7 +277,7 @@ void SnapResource::fetchScreenshots()
         screenshots << QUrl(screenshot->url());
     }
 #endif
-    Q_EMIT screenshotsFetched(screenshots, screenshots);
+    Q_EMIT screenshotsFetched(screenshots);
 }
 
 void SnapResource::invokeApplication() const
@@ -310,6 +311,7 @@ QDate SnapResource::releaseDate() const
 
 class PlugsModel : public QStandardItemModel
 {
+    Q_OBJECT
 public:
     enum Roles {
         PlugNameRole = Qt::UserRole + 1,
@@ -364,6 +366,9 @@ public:
         }
     }
 
+Q_SIGNALS:
+    void error(InlineMessage *message);
+
 private:
     bool setData(const QModelIndex &index, const QVariant &value, int role) override
     {
@@ -387,7 +392,7 @@ private:
         req->runSync();
         if (req->error()) {
             qWarning() << "snapd error" << req->errorString();
-            Q_EMIT m_res->backend()->passiveMessage(req->errorString());
+            Q_EMIT error(new InlineMessage(InlineMessage::Error, "error", req->errorString()));
         }
         return req->error() == QSnapdRequest::NoError;
     }
@@ -399,7 +404,7 @@ private:
 QAbstractItemModel *SnapResource::plugs(QObject *p)
 {
     if (!isInstalled())
-        return new QStandardItemModel(p);
+        return nullptr;
 
     return new PlugsModel(this, qobject_cast<SnapBackend *>(parent()), p);
 }
